summaryrefslogtreecommitdiff
path: root/hack
diff options
context:
space:
mode:
authorOpenShift Merge Robot <openshift-merge-robot@users.noreply.github.com>2020-06-03 22:12:33 +0200
committerGitHub <noreply@github.com>2020-06-03 22:12:33 +0200
commit1f8c509fafb4ce41970c4f28ed55daec459c7520 (patch)
tree65edb58d599b5d8fdbb3cb9d06bb47f9e14140ba /hack
parent986a277a962aef8d975996d494a4522299f6973b (diff)
parent9263ed2ab1c87dd798a37ac260e3e81c00a59448 (diff)
downloadpodman-1f8c509fafb4ce41970c4f28ed55daec459c7520.tar.gz
podman-1f8c509fafb4ce41970c4f28ed55daec459c7520.tar.bz2
podman-1f8c509fafb4ce41970c4f28ed55daec459c7520.zip
Merge pull request #6478 from rhatdan/abisupport
Remove use of ABISupport buildtag
Diffstat (limited to 'hack')
-rwxr-xr-xhack/golangci-lint.sh6
1 files changed, 3 insertions, 3 deletions
diff --git a/hack/golangci-lint.sh b/hack/golangci-lint.sh
index f4e60d8f5..8c81a3743 100755
--- a/hack/golangci-lint.sh
+++ b/hack/golangci-lint.sh
@@ -5,12 +5,12 @@
declare -A BUILD_TAGS
# TODO: add systemd tag
BUILD_TAGS[default]="apparmor,seccomp,selinux"
-BUILD_TAGS[abi]="${BUILD_TAGS[default]},ABISupport,varlink,!remoteclient"
-BUILD_TAGS[tunnel]="${BUILD_TAGS[default]},!ABISupport,varlink,remoteclient"
+BUILD_TAGS[abi]="${BUILD_TAGS[default]},varlink,!remoteclient"
+BUILD_TAGS[tunnel]="${BUILD_TAGS[default]},remote,varlink,remoteclient"
declare -A SKIP_DIRS
SKIP_DIRS[abi]=""
# TODO: add "ABISupport" build tag to pkg/api
SKIP_DIRS[tunnel]="pkg/api"
[[ $1 == run ]] && shift
@@ -5,12 +5,12 @@
declare -A SKIP_DIRS
SKIP_DIRS[abi]=""
-# TODO: add "ABISupport" build tag to pkg/api
+# TODO: add "remote" build tag to pkg/api
SKIP_DIRS[tunnel]="pkg/api"
[[ $1 == run ]] && shift